@@ -456,7 +456,12 @@ def start_postgres(config):
     _logger.info('Starting container %s', config['postgres_container'])
     container = _cli.create_container(image=config['postgres_image'],
                                       name=config['postgres_container'],
-                                      environment={'POSTGRES_PASSWORD': 'postgres'})
+                                      environment={'POSTGRES_PASSWORD': 'postgres',
+                                                   'PGDATA': '/var/lib/postgresql/data/pgdata'},
+                                      volumes=['/var/lib/postgresql/data/pgdata', ],
+                                      host_config=_cli.create_host_config(tmpfs={
+                                          '/var/lib/postgresql/data/pgdata': '',
+                                      }))
     _cli.start(container=container.get('Id'))
     _logger.info(container)
 
@@ -629,12 +634,12 @@ def test_module(config):
         with tempfile.NamedTemporaryFile("w") as f_sql:
             # Using ROLLBACK in order to avoid errors because of constraints
             # e.g. "CREATE ROLE" more than one time raises "already exists"
-            f_sql.write("BEGIN;\n%s\nROLLBACK;" % join_prefix_suffix(
+            f_sql.write("BEGIN;\n%s;\nROLLBACK;" % join_prefix_suffix(
                 deactivate2queries(instance_type), prefix="", suffix=";"))
             f_sql.flush()
             subprocess.call(["docker", "cp", f_sql.name, "%s:%s" % (config['container_name'], sql_container_fname)])
         exec_cmd(config['container_name'], ["chown", "odoo:odoo", sql_container_fname])
-        cmd_query = ["/bin/sh", "-c", 'psql test -aXtAf "%s" && echo "pass"' % sql_container_fname]
+        cmd_query = ["/bin/sh", "-c", 'psql test -v ON_ERROR_STOP=1 -aXtAf "%s" && echo "pass"' % sql_container_fname]
         query_res = exec_cmd(config['container_name'], cmd_query, 'odoo')
         query_res_lines = query_res.splitlines()
         if "pass" in query_res_lines[-1:]:
